% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1126.134767269639951 ; 1128.564814006228744 ];

%-- Principal point:
cc = [ 521.238759539963439 ; 502.126753069722838 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.145757857007840 ; 0.366522175477881 ; -0.003187265815964 ; 0.002139745973652 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.170315061796503 ; 3.161026444984447 ];

%-- Principal point uncertainty:
cc_error = [ 4.414785259474204 ; 3.345099618011152 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.019546616673191 ; 0.284921777968848 ; 0.000655769228043 ; 0.000886360463582 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -2.445071e+00 ; 2.634764e-01 ; -1.345874e+00 ];
Tc_1  = [ -3.704684e+02 ; 8.327974e+02 ; 3.578415e+03 ];
omc_error_1 = [ 3.126129e-03 ; 3.522031e-03 ; 7.324029e-03 ];
Tc_error_1  = [ 4.986352e+00 ; 3.773666e+00 ; 3.915018e+00 ];

